@@ -1,3 +1,4 @@
+import copy
 import sys
 import warnings
 from typing import Union, Iterable
@@ -154,7 +155,7 @@ class GeometricData(object):
         if idx is None:
             idx = self.df.index
         idx = np.atleast_1d(idx)
-        if attribute is 'series':
+        if attribute == 'series':
             if surfaces.df.loc[~surfaces.df['isBasement']]['series'].isna().sum() != 0:
                 raise AttributeError('Surfaces does not have the correspondent series assigned. See'
                                      'Surfaces.map_series_from_series.')
@@ -208,18 +209,17 @@ class SurfacePoints(GeometricData):
         self._columns_i_all = ['X', 'Y', 'Z', 'surface', 'series', 'X_std', 'Y_std', 'Z_std',
                                'order_series', 'surface_number']
 
-        self._columns_i_1 = ['X', 'Y', 'Z', 'X_r', 'Y_r', 'Z_r', 'surface', 'series', 'id',
+        self._columns_i_1 = ['X', 'Y', 'Z', 'X_c', 'Y_c', 'Z_c', 'surface', 'series', 'id',
                              'order_series', 'isFault', 'smooth']
 
         self._columns_rep = ['X', 'Y', 'Z', 'surface', 'series']
-        self._columns_i_num = ['X', 'Y', 'Z', 'X_r', 'Y_r', 'Z_r']
+        self._columns_i_num = ['X', 'Y', 'Z', 'X_c', 'Y_c', 'Z_c']
         self._columns_rend = ['X', 'Y', 'Z', 'smooth', 'surface']
-
-        if (np.array(sys.version_info[:2]) <= np.array([3, 6])).all():
-            self.df: pn.DataFrame
-
         self.set_surface_points(coord, surface)
 
+        self.df['order_series'] = self.df['order_series'].astype('int')
+        self.df['id'] = self.df['id'].astype('int')
+
     @_setdoc_pro([ds.coord, ds.surface_sp])
     def set_surface_points(self, coord: np.ndarray = None, surface: list = None):
         """
@@ -232,7 +232,7 @@ class SurfacePoints(GeometricData):
         Returns:
             :class:`SurfacePoints`
         """
-        self.df = pn.DataFrame(columns=['X', 'Y', 'Z', 'X_r', 'Y_r', 'Z_r', 'surface'], dtype=float)
+        self.df = pn.DataFrame(columns=['X', 'Y', 'Z', 'X_c', 'Y_c', 'Z_c', 'surface'], dtype=float)
 
         if coord is not None and surface is not None:
             self.df[['X', 'Y', 'Z']] = pn.DataFrame(coord)
@@ -372,6 +372,9 @@ class SurfacePoints(GeometricData):
             values = values.T
 
         # Selecting the properties passed to be modified
+        if values.shape[0] == 1:
+            values = np.repeat(values, idx.shape[0])
+
         self.df.loc[idx, list(kwargs.keys())] = values
 
         return self
@@ -484,9 +487,9 @@ class Orientations(GeometricData):
         super().__init__(surfaces)
         self._columns_o_all = ['X', 'Y', 'Z', 'G_x', 'G_y', 'G_z', 'dip', 'azimuth', 'polarity',
                                'surface', 'series', 'id', 'order_series', 'surface_number']
-        self._columns_o_1 = ['X', 'Y', 'Z', 'X_r', 'Y_r', 'Z_r', 'G_x', 'G_y', 'G_z', 'dip', 'azimuth', 'polarity',
+        self._columns_o_1 = ['X', 'Y', 'Z', 'X_c', 'Y_c', 'Z_c', 'G_x', 'G_y', 'G_z', 'dip', 'azimuth', 'polarity',
                              'surface', 'series', 'id', 'order_series', 'isFault']
-        self._columns_o_num = ['X', 'Y', 'Z', 'X_r', 'Y_r', 'Z_r', 'G_x', 'G_y', 'G_z', 'dip', 'azimuth', 'polarity']
+        self._columns_o_num = ['X', 'Y', 'Z', 'X_c', 'Y_c', 'Z_c', 'G_x', 'G_y', 'G_z', 'dip', 'azimuth', 'polarity']
         self._columns_rend = ['X', 'Y', 'Z', 'G_x', 'G_y', 'G_z', 'smooth', 'surface']
 
         if (np.array(sys.version_info[:2]) <= np.array([3, 6])).all():
@@ -511,7 +514,7 @@ class Orientations(GeometricData):
         Returns:
 
         """
-        self.df = pn.DataFrame(columns=['X', 'Y', 'Z', 'X_r', 'Y_r', 'Z_r', 'G_x', 'G_y', 'G_z', 'dip',
+        self.df = pn.DataFrame(columns=['X', 'Y', 'Z', 'X_c', 'Y_c', 'Z_c', 'G_x', 'G_y', 'G_z', 'dip',
                                         'azimuth', 'polarity', 'surface'], dtype=float)
 
         self.df['surface'] = self.df['surface'].astype('category', copy=True)
@@ -685,6 +688,9 @@ class Orientations(GeometricData):
         if type(idx) is list or type(idx) is np.ndarray:
             values = values.T
 
+        if values.shape[0] == 1:
+            values = np.repeat(values, idx.shape[0])
+
         # Selecting the properties passed to be modified
         self.df.loc[idx, list(kwargs.keys())] = values.astype('float64')
 
@@ -951,7 +957,7 @@ class Orientations(GeometricData):
 
 
 @_setdoc_pro([SurfacePoints.__doc__, Orientations.__doc__, Grid.__doc__])
-class RescaledData(object):
+class ScalingSystem(object):
     """
     Auxiliary class to rescale the coordinates between 0 and 1 to increase float stability.
 
@@ -972,6 +978,11 @@ class RescaledData(object):
     def __init__(self, surface_points: SurfacePoints, orientations: Orientations, grid: Grid,
                  rescaling_factor: float = None, centers: Union[list, pn.DataFrame] = None):
 
+        self.axial_anisotropy = False
+        self.max_coord = np.zeros(3)
+        self.min_coord = np.zeros(3)
+        self.axial_anisotropy_type = 'data'
+
         self.surface_points = surface_points
         self.orientations = orientations
         self.grid = grid
@@ -988,6 +999,11 @@ class RescaledData(object):
     def _repr_html_(self):
         return self.df.T.to_html()
 
+    def toggle_axial_anisotropy(self, type='data'):
+        self.axial_anisotropy_type = type
+        self.axial_anisotropy = self.axial_anisotropy ^ True
+        self.rescale_data()
+
     @_setdoc_pro([ds.centers, ds.rescaling_factor])
     def modify_rescaling_parameters(self, attribute, value):
         """
@@ -1008,7 +1024,7 @@ class RescaledData(object):
 
         if attribute == 'centers':
             try:
-                assert value.shape[0] is 3
+                assert value.shape[0] == 3
 
                 self.df.loc['values', attribute] = value
 
@@ -1021,7 +1037,11 @@ class RescaledData(object):
         return self
 
     @_setdoc_pro([ds.centers, ds.rescaling_factor])
-    def rescale_data(self, rescaling_factor=None, centers=None):
+    def rescale_data(self,
+                     rescaling_factor=None,
+                     centers=None,
+                     axial_anisotropy=None
+                     ):
         """
         Rescale inplace: surface_points, orientations---adding columns in the categories_df---and grid---adding values_r
         attributes. The rescaled values will get stored on the linked objects.
@@ -1033,32 +1053,65 @@ class RescaledData(object):
         Returns:
 
         """
-        max_coord, min_coord = self.max_min_coord(self.surface_points, self.orientations)
+
+        xyz = self.concat_surface_points_orientations(self.surface_points.df[['X', 'Y', 'Z']],
+                                                      self.orientations.df[['X', 'Y', 'Z']])
+
+        # This is asking for XYZ parameters
+        max_coord, min_coord = self.max_min_coord(xyz)
+
         if rescaling_factor is None:
-            self.df['rescaling factor'] = self.compute_rescaling_factor(self.surface_points, self.orientations,
-                                                                        max_coord, min_coord)
+            # This is asking for XYZ parameters
+            self.df['rescaling factor'] = self.compute_rescaling_factor_for_0_1(max_coord=max_coord,
+                                                                                min_coord=min_coord)
         else:
             self.df['rescaling factor'] = rescaling_factor
         if centers is None:
-            self.df.at['values', 'centers'] = self.compute_data_center(self.surface_points, self.orientations,
-                                                                       max_coord, min_coord)
+            # This is asking for XYZ parameters
+            self.df.at['values', 'centers'] = self.compute_data_center(max_coord=max_coord,
+                                                                       min_coord=min_coord)
         else:
             self.df.at['values', 'centers'] = centers
 
-        self.set_rescaled_surface_points()
-        self.set_rescaled_orientations()
-        self.set_rescaled_grid()
+        self.set_rescaled_surface_points(axial_anisotropy=axial_anisotropy)
+        self.set_rescaled_orientations(axial_anisotropy=axial_anisotropy)
+        self.set_rescaled_grid(axial_anisotropy=axial_anisotropy)
         return True
 
+    def compute_axial_anisotropy(self, type=None, extent=None):
+        if type is None:
+            type = self.axial_anisotropy_type
+
+        if type == 'data':
+            x1, y1, z1 = self.max_coord
+            x0, y0, z0 = self.min_coord
+        elif type == 'extent':
+            if extent is None:
+                extent = self.grid.regular_grid.extent
+
+            x0, x1, y0, y1, z0, z1 = extent
+        else:
+            raise AttributeError('Type must be either data or extent')
+
+        # Calculate average
+        x_d = np.linalg.norm(x0-x1)
+        y_d = np.linalg.norm(y0-y1)
+        z_d = np.linalg.norm(z0-z1)
+        mean_d = np.mean([x_d, y_d, z_d])
+        return np.array([mean_d/x_d, mean_d/y_d, mean_d/z_d])
+
+    def apply_axial_anisotropy(self, xyz, anisotropy):
+        return xyz * anisotropy
+
     def get_rescaled_surface_points(self):
         """
         Get the rescaled coordinates. return an image of the interface and orientations categories_df with the X_r..
          columns
 
         Returns:
-            :attr:`SurfacePoints.df[['X_r', 'Y_r', 'Z_r']]`
+            :attr:`SurfacePoints.df[['X_c', 'Y_c', 'Z_c']]`
         """
-        return self.surface_points.df[['X_r', 'Y_r', 'Z_r']],
+        return self.surface_points.df[['X_c', 'Y_c', 'Z_c']]
 
     def get_rescaled_orientations(self):
         """
@@ -1066,47 +1119,59 @@ class RescaledData(object):
          columns.
 
         Returns:
-            :attr:`Orientations.df[['X_r', 'Y_r', 'Z_r']]`
+            :attr:`Orientations.df[['X_c', 'Y_c', 'Z_c']]`
         """
-        return self.orientations.df[['X_r', 'Y_r', 'Z_r']]
+        return self.orientations.df[['X_c', 'Y_c', 'Z_c']]
 
     @staticmethod
+    def concat_surface_points_orientations(surface_points_xyz=None, orientations_xyz=None) \
+            -> pn.DataFrame:
+        """
+        Args:
+            surface_points_xyz (:class:`pandas.DataFrame`): [s0]
+            orientations_xyz (:class:`pandas.DataFrame`): [s1]
+        Returns:
+
+        """
+
+        if surface_points_xyz is None and orientations_xyz is not None:
+            df = orientations_xyz
+        elif surface_points_xyz is not None and orientations_xyz is None:
+            df = surface_points_xyz
+        elif surface_points_xyz is not None and orientations_xyz is not None:
+            df = pn.concat([orientations_xyz, surface_points_xyz], sort=False)
+        else:
+            raise AttributeError('You must pass at least one Data object')
+        return df
+
     @_setdoc_pro([SurfacePoints.__doc__, Orientations.__doc__])
-    def max_min_coord(surface_points=None, orientations=None):
+    def max_min_coord(self, df):
         """
         Find the maximum and minimum location of any input data in each cartesian coordinate
 
         Args:
-            surface_points (:class:`SurfacePoints`): [s0]
-            orientations (:class:`Orientations`): [s1]
+            df
 
         Returns:
             tuple: max[XYZ], min[XYZ]
         """
-        if surface_points is None:
-            if orientations is None:
-                raise AttributeError('You must pass at least one Data object')
-            else:
-                df = orientations.df
-        else:
-            if orientations is None:
-                df = surface_points.df
-            else:
-                df = pn.concat([orientations.df, surface_points.df], sort=False)
 
-        max_coord = df.max()[['X', 'Y', 'Z']]
-        min_coord = df.min()[['X', 'Y', 'Z']]
-        return max_coord, min_coord
+        self.max_coord = df.max()[['X', 'Y', 'Z']]
+        self.min_coord = df.min()[['X', 'Y', 'Z']]
+
+        return self.max_coord, self.min_coord
 
     @_setdoc_pro([SurfacePoints.__doc__, Orientations.__doc__, ds.centers])
-    def compute_data_center(self, surface_points=None, orientations=None,
+    def compute_data_center(self,
+                            surface_points_xyz=None,
+                            orientations_xyz=None,
                             max_coord=None, min_coord=None, inplace=True):
         """
         Calculate the center of the data once it is shifted between 0 and 1.
 
         Args:
-            surface_points (:class:`SurfacePoints`): [s0]
-            orientations (:class:`Orientations`): [s1]
+            surface_points_xyz (:class:`pandas.DataFrame`): [s0]
+            orientations_xyz (:class:`pandas.DataFrame`): [s1]
             max_coord (float): Max XYZ coordinates of all GeometricData
             min_coord (float): Min XYZ coordinates of all GeometricData
             inplace (bool): if True modify the self.df rescaling factor attribute
@@ -1116,7 +1181,7 @@ class RescaledData(object):
         """
 
         if max_coord is None or min_coord is None:
-            max_coord, min_coord = self.max_min_coord(surface_points, orientations)
+            max_coord, min_coord = self.max_min_coord(surface_points_xyz, orientations_xyz)
 
         # Get the centers of every axis
         centers = ((max_coord + min_coord) / 2).astype(float).values
@@ -1124,19 +1189,18 @@ class RescaledData(object):
             self.df.at['values', 'centers'] = centers
         return centers
 
-    # def update_centers(self, surface_points=None, orientations=None, max_coord=None, min_coord=None):
-    #     # TODO this should update the additional data
-    #     self.compute_data_center(surface_points, orientations, max_coord, min_coord, inplace=True)
-
     @_setdoc_pro([SurfacePoints.__doc__, Orientations.__doc__, ds.rescaling_factor])
-    def compute_rescaling_factor(self, surface_points=None, orientations=None,
-                                 max_coord=None, min_coord=None, inplace=True):
+    def compute_rescaling_factor_for_0_1(self,
+                                         surface_points_xyz=None,
+                                         orientations_xyz=None,
+                                         max_coord=None, min_coord=None,
+                                         inplace=True):
         """
         Calculate the rescaling factor of the data to keep all coordinates between 0 and 1
 
         Args:
-            surface_points (:class:`SurfacePoints`): [s0]
-            orientations (:class:`Orientations`): [s1]
+            surface_points_xyz (:class:`pandas.DataFrame`): [s0]
+            orientations_xyz (:class:`pandas.DataFrame`): [s1]
             max_coord (float): Max XYZ coordinates of all GeometricData
             min_coord (float): Min XYZ coordinates of all GeometricData
             inplace (bool): if True modify the self.df rescaling factor attribute
@@ -1146,24 +1210,24 @@ class RescaledData(object):
         """
 
         if max_coord is None or min_coord is None:
-            max_coord, min_coord = self.max_min_coord(surface_points, orientations)
+            max_coord, min_coord = self.max_min_coord(surface_points_xyz, orientations_xyz)
         rescaling_factor_val = (2 * np.max(max_coord - min_coord))
         if inplace is True:
             self.df['rescaling factor'] = rescaling_factor_val
         return rescaling_factor_val
 
-    # def update_rescaling_factor(self, surface_points=None, orientations=None,
-    #                             max_coord=None, min_coord=None):
-    #     self.compute_rescaling_factor(surface_points, orientations, max_coord, min_coord, inplace=True)
-
     @staticmethod
-    @_setdoc_pro([SurfacePoints.__doc__, compute_data_center.__doc__, compute_rescaling_factor.__doc__, ds.idx_sp])
-    def rescale_surface_points(surface_points, rescaling_factor, centers, idx: list = None):
+    @_setdoc_pro([SurfacePoints.__doc__, compute_data_center.__doc__,
+                  compute_rescaling_factor_for_0_1.__doc__, ds.idx_sp])
+    def rescale_surface_points(surface_points_xyz,
+                               rescaling_factor,
+                               centers=None,
+                               idx: list = None):
         """
         Rescale inplace: surface_points. The rescaled values will get stored on the linked objects.
 
         Args:
-            surface_points (:class:`SurfacePoints`): [s0]
+            surface_points_xyz (:class:`pandas.DataFrame`): [s0]
             rescaling_factor: [s2]
             centers: [s1]
             idx (int, list of int): [s3]
@@ -1173,21 +1237,25 @@ class RescaledData(object):
         """
 
         if idx is None:
-            idx = surface_points.df.index
+            idx = surface_points_xyz.index
 
         # Change the coordinates of surface_points
-        new_coord_surface_points = (surface_points.df.loc[idx, ['X', 'Y', 'Z']] -
+        new_coord_surface_points = (surface_points_xyz.loc[idx, ['X', 'Y', 'Z']] -
                                     centers) / rescaling_factor + 0.5001
 
-        new_coord_surface_points.rename(columns={"X": "X_r", "Y": "Y_r", "Z": 'Z_r'}, inplace=True)
+        new_coord_surface_points.rename(columns={"X": "X_c", "Y": "Y_c", "Z": 'Z_c'},
+                                        inplace=True)
         return new_coord_surface_points
 
     @_setdoc_pro(ds.idx_sp)
-    def set_rescaled_surface_points(self, idx: Union[list, np.ndarray] = None):
+    def set_rescaled_surface_points(self,
+                                    idx: Union[list, np.ndarray] = None,
+                                    axial_anisotropy=None):
         """
         Set the rescaled coordinates into the surface_points categories_df
 
         Args:
+            axial_anisotropy:
             idx (int, list of int): [s0]
 
         Returns:
@@ -1197,13 +1265,31 @@ class RescaledData(object):
             idx = self.surface_points.df.index
         idx = np.atleast_1d(idx)
 
-        self.surface_points.df.loc[idx, ['X_r', 'Y_r', 'Z_r']] = self.rescale_surface_points(
-            self.surface_points, self.df.loc['values', 'rescaling factor'], self.df.loc['values', 'centers'], idx=idx)
+        if axial_anisotropy is None:
+            axial_anisotropy = self.axial_anisotropy
 
-        return self.surface_points
+        if axial_anisotropy is False:
+            surface_points_xyz = self.surface_points.df
+        else:
+            axial_anisotropy_scale = self.compute_axial_anisotropy()
+            surface_points_xyz = self.apply_axial_anisotropy(
+                self.surface_points.df[['X', 'Y', 'Z']],
+                axial_anisotropy_scale)
+
+        self.surface_points.df.loc[idx, ['X_c', 'Y_c', 'Z_c']] = self.rescale_surface_points(
+            surface_points_xyz, # This is asking for XYZ parameters
+            self.df.loc['values', 'rescaling factor'],
+            self.df.loc['values', 'centers'],
+            idx=idx)
+
+        return self.surface_points.df.loc[idx, ['X_c', 'Y_c', 'Z_c']]
 
     def rescale_data_point(self, data_points: np.ndarray, rescaling_factor=None, centers=None):
-        """This method now is very similar to set_rescaled_surface_points passing an index"""
+        """This method now is very similar to set_rescaled_surface_points passing an index
+
+        Notes:
+            So far is not used by any function
+        """
         if rescaling_factor is None:
             rescaling_factor = self.df.loc['values', 'rescaling factor']
         if centers is None:
@@ -1214,13 +1300,13 @@ class RescaledData(object):
         return rescaled_data_point
 
     @staticmethod
-    @_setdoc_pro([Orientations.__doc__, compute_data_center.__doc__, compute_rescaling_factor.__doc__, ds.idx_sp])
-    def rescale_orientations(orientations, rescaling_factor, centers, idx: list = None):
+    @_setdoc_pro([Orientations.__doc__, compute_data_center.__doc__, compute_rescaling_factor_for_0_1.__doc__, ds.idx_sp])
+    def rescale_orientations(orientations_xyz, rescaling_factor, centers, idx: list = None):
         """
         Rescale inplace: surface_points. The rescaled values will get stored on the linked objects.
 
         Args:
-            orientations (:class:`Orientations`): [s0]
+            orientations_xyz (:class:`pandas.DataFrame`): [s0]
             rescaling_factor: [s2]
             centers: [s1]
             idx (int, list of int): [s3]
@@ -1229,22 +1315,26 @@ class RescaledData(object):
 
         """
         if idx is None:
-            idx = orientations.df.index
+            idx = orientations_xyz.index
 
         # Change the coordinates of orientations
-        new_coord_orientations = (orientations.df.loc[idx, ['X', 'Y', 'Z']] -
+        new_coord_orientations = (orientations_xyz.loc[idx, ['X', 'Y', 'Z']] -
                                   centers) / rescaling_factor + 0.5001
 
-        new_coord_orientations.rename(columns={"X": "X_r", "Y": "Y_r", "Z": 'Z_r'}, inplace=True)
+        new_coord_orientations.rename(columns={"X": "X_c", "Y": "Y_c", "Z": 'Z_c'}, inplace=True)
 
         return new_coord_orientations
 
     @_setdoc_pro(ds.idx_sp)
-    def set_rescaled_orientations(self, idx: Union[list, np.ndarray] = None):
+    def set_rescaled_orientations(self,
+                                  idx: Union[list, np.ndarray] = None,
+                                  axial_anisotropy=None
+                                  ):
         """
         Set the rescaled coordinates into the surface_points categories_df
 
         Args:
+            axial_anisotropy:
             idx (int, list of int): [s0]
 
         Returns:
@@ -1254,22 +1344,82 @@ class RescaledData(object):
             idx = self.orientations.df.index
         idx = np.atleast_1d(idx)
 
-        self.orientations.df.loc[idx, ['X_r', 'Y_r', 'Z_r']] = self.rescale_orientations(
-            self.orientations, self.df.loc['values', 'rescaling factor'], self.df.loc['values', 'centers'], idx=idx)
-        return True
+        if axial_anisotropy is None:
+            axial_anisotropy = self.axial_anisotropy
+
+        if axial_anisotropy is False:
+            orientations_xyz = self.orientations.df
+        else:
+            axial_anisotropy_scale = self.compute_axial_anisotropy()
+            orientations_xyz = self.apply_axial_anisotropy(
+                self.orientations.df[['X', 'Y', 'Z']],
+                axial_anisotropy_scale)
+
+        self.orientations.df.loc[idx, ['X_c', 'Y_c', 'Z_c']] = self.rescale_orientations(
+            orientations_xyz,
+            self.df.loc['values', 'rescaling factor'],
+            self.df.loc['values', 'centers'],
+            idx=idx
+        )
+        return self.orientations.df.loc[idx, ['X_c', 'Y_c', 'Z_c']]
 
     @staticmethod
-    def rescale_grid(grid, rescaling_factor, centers: pn.DataFrame):
-        new_grid_extent = (grid.regular_grid.extent - np.repeat(centers, 2)) / rescaling_factor + 0.5001
-        new_grid_values = (grid.values - centers) / rescaling_factor + 0.5001
+    def rescale_grid(grid_extent, grid_values, rescaling_factor, centers: pn.DataFrame):
+        new_grid_extent = (grid_extent - np.repeat(centers, 2)) / rescaling_factor + 0.5001
+        new_grid_values = (grid_values - centers) / rescaling_factor + 0.5001
         return new_grid_extent, new_grid_values,
 
-    def set_rescaled_grid(self):
+    def set_rescaled_grid(self, axial_anisotropy=None):
         """
         Set the rescaled coordinates and extent into a grid object
         """
+        if axial_anisotropy is None:
+            axial_anisotropy = self.axial_anisotropy
 
+        # The grid has to be rescaled for having the model in scaled coordinates
+        # between 0 and 1 but with the actual proportions
         self.grid.extent_r, self.grid.values_r = self.rescale_grid(
-            self.grid, self.df.loc['values', 'rescaling factor'], self.df.loc['values', 'centers'])
+            self.grid.regular_grid.extent,
+            self.grid.values,
+            self.df.loc['values', 'rescaling factor'],
+            self.df.loc['values', 'centers']
+        )
 
-        self.grid.regular_grid.extent_r, self.grid.regular_grid.values_r = self.grid.extent_r, self.grid.values_r
\ No newline at end of file
+        self.grid.regular_grid.extent_r, self.grid.regular_grid.values_r = self.grid.extent_r, self.grid.values_r
+
+        # For the grid
+
+        if axial_anisotropy is True:
+
+            axial_anisotropy_scale = self.compute_axial_anisotropy()
+
+            ani_grid_values = self.apply_axial_anisotropy(
+                self.grid.values,
+                axial_anisotropy_scale)
+
+            axis_extended_l = self.apply_axial_anisotropy(
+                self.grid.regular_grid.extent[[0, 2, 4]],
+                axial_anisotropy_scale)
+
+            axis_extended_r = self.apply_axial_anisotropy(
+                self.grid.regular_grid.extent[[1, 3, 5]],
+                axial_anisotropy_scale)
+
+            ani_grid_extent = np.array([axis_extended_l[0],
+                                        axis_extended_r[0],
+                                        axis_extended_l[1],
+                                        axis_extended_r[1],
+                                        axis_extended_l[2],
+                                        axis_extended_r[2]])
+
+            self.grid.extent_c, self.grid.values_c = self.rescale_grid(
+                ani_grid_extent,
+                ani_grid_values,
+                self.df.loc['values', 'rescaling factor'],
+                self.df.loc['values', 'centers']
+            )
+        else:
+            self.grid.values_c = self.grid.values_r
+            self.grid.extent_c = self.grid.extent_r
+
+        return self.grid.values_c
