@@ -29,6 +29,8 @@ def artificial_grid(one_fault_model_no_interp):
     return topo
 
 
+@pytest.mark.skipif("TRAVIS" in os.environ and os.environ["TRAVIS"] == "true",
+                    reason="Skipping this test on Travis CI because gdal.")
 def test_real_grid_ales():
     resolution = [30, 20, 50]
     extent = np.array([729550.0, 751500.0, 1913500.0, 1923650.0, -50, 800.0])
